==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Dvs.java <==
package com.example.model;

/**
 * Model for Dvs
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "Dvs", description = "Model for Dvs")
@javax.xml.bind.annotation.XmlRootElement(name = "Dvs")
public class Dvs implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.Components components = null;
	private java.lang.String label = null;
	private java.lang.String result = null;
	
	/**
	 * Model for Components
	 */
	public Dvs components(com.example.model.Components components) {
		setComponents(components);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for Components")
	@com.fasterxml.jackson.annotation.JsonProperty("components")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.Components getComponents() {
		return this.components;
	}
	public void setComponents(com.example.model.Components components) {
		this.components = components;
	}
	
	/**
	 */
	public Dvs label(java.lang.String label) {
		setLabel(label);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("label")
	public java.lang.String getLabel() {
		return this.label;
	}
	public void setLabel(java.lang.String label) {
		this.label = label;
	}
	
	/**
	 */
	public Dvs result(java.lang.String result) {
		setResult(result);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("result")
	public java.lang.String getResult() {
		return this.result;
	}
	public void setResult(java.lang.String result) {
		this.result = result;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Dvs dvs = (Dvs) o;
		return java.util.Objects.equals(this.components, dvs.components)
				&& java.util.Objects.equals(this.label, dvs.label)
				&& java.util.Objects.equals(this.result, dvs.result);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.components, this.label, this.result);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Dvs {\n");
		
		sb.append("    components: ").append(toIndentedString(this.components)).append("\n");
		sb.append("    label: ").append(toIndentedString(this.label)).append("\n");
		sb.append("    result: ").append(toIndentedString(this.result)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Dvs.java <==
package com.example.model;

/**
 * Model for Dvs
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Dvs", description = "Model for Dvs")
@javax.xml.bind.annotation.XmlRootElement(name = "Dvs")
public class Dvs implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.Components components = null;
	private java.lang.String label = null;
	private java.lang.String result = null;
	
	/**
	 * Model for Components
	 */
	public Dvs components(com.example.model.Components components) {
		setComponents(components);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "components", description = "Model for Components")
	@com.fasterxml.jackson.annotation.JsonProperty("components")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.Components getComponents() {
		return this.components;
	}
	public void setComponents(com.example.model.Components components) {
		this.components = components;
	}
	
	/**
	 */
	public Dvs label(java.lang.String label) {
		setLabel(label);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "label")
	@com.fasterxml.jackson.annotation.JsonProperty("label")
	public java.lang.String getLabel() {
		return this.label;
	}
	public void setLabel(java.lang.String label) {
		this.label = label;
	}
	
	/**
	 */
	public Dvs result(java.lang.String result) {
		setResult(result);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "result")
	@com.fasterxml.jackson.annotation.JsonProperty("result")
	public java.lang.String getResult() {
		return this.result;
	}
	public void setResult(java.lang.String result) {
		this.result = result;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Dvs dvs = (Dvs) o;
		return java.util.Objects.equals(this.components, dvs.components)
				&& java.util.Objects.equals(this.label, dvs.label)
				&& java.util.Objects.equals(this.result, dvs.result);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.components, this.label, this.result);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Dvs {\n");
		
		sb.append("    components: ").append(toIndentedString(this.components)).append("\n");
		sb.append("    label: ").append(toIndentedString(this.label)).append("\n");
		sb.append("    result: ").append(toIndentedString(this.result)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
